package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBillsLubeInstanceActivity;

/**
 * 润滑工单实例节点Mapper接口
 *
 * @author Open Platform
 * @date 2024-02-26
 */
public interface DmsBillsLubeInstanceActivityMapper
{
    /**
     * 查询润滑工单实例节点
     *
     * @param instanceActivityId 润滑工单实例节点主键
     * @return 润滑工单实例节点
     */
    public DmsBillsLubeInstanceActivity selectDmsBillsLubeInstanceActivityByInstanceActivityId(Long instanceActivityId);

    /**
     * 查询润滑工单实例节点列表
     *
     * @param dmsBillsLubeInstanceActivity 润滑工单实例节点
     * @return 润滑工单实例节点集合
     */
    public List<DmsBillsLubeInstanceActivity> selectDmsBillsLubeInstanceActivityList(DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity);

    /**
     * 新增润滑工单实例节点
     *
     * @param dmsBillsLubeInstanceActivity 润滑工单实例节点
     * @return 结果
     */
    public int insertDmsBillsLubeInstanceActivity(DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity);

    /**
     * 修改润滑工单实例节点
     *
     * @param dmsBillsLubeInstanceActivity 润滑工单实例节点
     * @return 结果
     */
    public int updateDmsBillsLubeInstanceActivity(DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity);

    /**
     * 删除润滑工单实例节点
     *
     * @param instanceActivityId 润滑工单实例节点主键
     * @return 结果
     */
    public int deleteDmsBillsLubeInstanceActivityByInstanceActivityId(Long instanceActivityId);

    /**
     * 批量删除润滑工单实例节点
     *
     * @param instanceActivityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBillsLubeInstanceActivityByInstanceActivityIds(Long[] instanceActivityIds);

    Long[] selectUserIdByDmsBillsLubeInstanceActivityId(Long repairInstanceId);
}
