package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBillsLubeInstanceActivity;
import com.hw.dms.service.IDmsBillsLubeInstanceActivityService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 润滑工单实例节点Controller
 *
 * @author Open Platform
 * @date 2024-02-26
 */
@RestController
@RequestMapping("/dmsBillsLubeInstanceActivity")
public class DmsBillsLubeInstanceActivityController extends BaseController
{
    @Autowired
    private IDmsBillsLubeInstanceActivityService dmsBillsLubeInstanceActivityService;

    /**
     * 查询润滑工单实例节点列表
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        startPage();
        List<DmsBillsLubeInstanceActivity> list = dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityList(dmsBillsLubeInstanceActivity);
        return getDataTable(list);
    }

    /**
     * 导出润滑工单实例节点列表
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:export")
    @Log(title = "润滑工单实例节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        List<DmsBillsLubeInstanceActivity> list = dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityList(dmsBillsLubeInstanceActivity);
        ExcelUtil<DmsBillsLubeInstanceActivity> util = new ExcelUtil<DmsBillsLubeInstanceActivity>(DmsBillsLubeInstanceActivity.class);
        util.exportExcel(response, list, "润滑工单实例节点数据");
    }

    /**
     * 获取润滑工单实例节点详细信息
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:query")
    @GetMapping(value = "/{instanceActivityId}")
    public AjaxResult getInfo(@PathVariable("instanceActivityId") Long instanceActivityId)
    {
        return success(dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityByInstanceActivityId(instanceActivityId));
    }

    /**
     * 新增润滑工单实例节点
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:add")
    @Log(title = "润滑工单实例节点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.insertDmsBillsLubeInstanceActivity(dmsBillsLubeInstanceActivity));
    }

    /**
     * 修改润滑工单实例节点
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:edit")
    @Log(title = "润滑工单实例节点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.updateDmsBillsLubeInstanceActivity(dmsBillsLubeInstanceActivity));
    }

    /**
     * 删除润滑工单实例节点
     */
    @RequiresPermissions("dms:dmsBillsLubeInstanceActivity:remove")
    @Log(title = "润滑工单实例节点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{instanceActivityIds}")
    public AjaxResult remove(@PathVariable Long[] instanceActivityIds)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.deleteDmsBillsLubeInstanceActivityByInstanceActivityIds(instanceActivityIds));
    }
    @GetMapping("/selectUserIdByDmsBillsLubeInstanceActivityId/{instanceActivityId}/userId/{userId}")
    public boolean selectUserIdByDmsBillsLubeInstanceActivityId(@PathVariable("instanceActivityId") Long inspectInstanceId,@PathVariable("userId") Long userId){
      return   dmsBillsLubeInstanceActivityService.selectUserIdByDmsBillsLubeInstanceActivityId(inspectInstanceId,userId);
    }
}
